pub struct BeePool { /* private fields */ }Expand description
Pool of bees that routes tasks to idle workers.
Implementations
Sourceimpl BeePool
impl BeePool
Sourcepub fn new(config: &NodeConfig) -> Self
pub fn new(config: &NodeConfig) -> Self
Create a new BeePool with N bees (N = config.cores), each with memory_per_bee budget.
Sourcepub async fn queue_size(&self) -> usize
pub async fn queue_size(&self) -> usize
Return the current number of queued tasks.
Sourcepub async fn busy_count(&self) -> usize
pub async fn busy_count(&self) -> usize
Return the current number of busy bees.
Sourcepub fn avg_memory_utilisation(&self) -> f64
pub fn avg_memory_utilisation(&self) -> f64
Return the average memory utilization across all bees.
Sourcepub async fn submit<F>(
&self,
func: F,
) -> JoinHandle<Result<Vec<RecordBatch>, ApiaryError>>
pub async fn submit<F>( &self, func: F, ) -> JoinHandle<Result<Vec<RecordBatch>, ApiaryError>>
Submit a task to the pool. If all bees are busy the task is queued. Returns the task result via the returned JoinHandle.
When colony temperature indicates Critical state (> 0.95), tasks are rejected immediately to protect the system from overload.