pub struct WorldView {
pub nodes: HashMap<NodeId, NodeStatus>,
pub updated_at: DateTime<Utc>,
}Expand description
A snapshot of all known nodes in the swarm.
Fields
nodes: HashMap<NodeId, NodeStatus>updated_at: DateTime<Utc>Implementations
Sourceimpl WorldView
impl WorldView
Sourcepub fn alive_nodes(&self) -> Vec<&NodeStatus>
pub fn alive_nodes(&self) -> Vec<&NodeStatus>
Return only alive nodes.
Sourcepub fn total_bees(&self) -> usize
pub fn total_bees(&self) -> usize
Return the total number of bees across alive nodes.
Sourcepub fn total_idle_bees(&self) -> usize
pub fn total_idle_bees(&self) -> usize
Return the total number of idle bees across alive nodes.