pub struct WorldViewBuilder { /* private fields */ }Expand description
Periodically polls the heartbeat prefix and builds the world view.
Implementations
Sourceimpl WorldViewBuilder
impl WorldViewBuilder
Sourcepub fn new(
storage: Arc<dyn StorageBackend>,
poll_interval: Duration,
dead_threshold: Duration,
) -> Self
pub fn new( storage: Arc<dyn StorageBackend>, poll_interval: Duration, dead_threshold: Duration, ) -> Self
Create a new world view builder.
Sourcepub fn world_view(&self) -> Arc<RwLock<WorldView>>
pub fn world_view(&self) -> Arc<RwLock<WorldView>>
Return a shared handle to the world view.
Sourcepub async fn build_once(&self) -> Result<WorldView>
pub async fn build_once(&self) -> Result<WorldView>
Build the world view once by reading all heartbeat files.
Sourcepub async fn poll_once(&self) -> Result<WorldView>
pub async fn poll_once(&self) -> Result<WorldView>
Poll once, update the shared world view, and return it.
Sourcepub async fn run(&self, cancel: Receiver<bool>)
pub async fn run(&self, cancel: Receiver<bool>)
Run the world view builder loop until cancellation.
Sourcepub async fn cleanup_stale(&self, cleanup_age: Duration) -> Result<usize>
pub async fn cleanup_stale(&self, cleanup_age: Duration) -> Result<usize>
Clean up heartbeat files for nodes that have been dead longer than cleanup_age.