The Apiary node โ a stateless compute instance in the swarm.
ApiaryNode is the main runtime entry point. It initialises the
storage backend, detects system capacity, creates the bee pool,
starts the heartbeat writer and world view builder, and manages
the node lifecycle.
Structs
- Apiary
Node - An Apiary compute node โ the runtime for one machine in the swarm.
- Colony
Status - Colony temperature and regulation status.
- Swarm
Node Info - Info about a single node in the swarm.
- Swarm
Status - Summary of the swarm as seen by this node.