pub struct AbandonmentTracker { /* private fields */ }Expand description
Tracker for task failures that decides when to abandon failing tasks.
Tasks that repeatedly fail are abandoned rather than retried indefinitely. This prevents the colony from wasting effort on unrecoverable work.
Implementations
Sourceimpl AbandonmentTracker
impl AbandonmentTracker
Sourcepub fn new(trial_limit: u32) -> Self
pub fn new(trial_limit: u32) -> Self
Create a new abandonment tracker with the given trial limit.
Sourcepub fn record_failure(&self, task_id: &TaskId) -> AbandonmentDecision
pub fn record_failure(&self, task_id: &TaskId) -> AbandonmentDecision
Sourcepub fn record_success(&self, task_id: &TaskId)
pub fn record_success(&self, task_id: &TaskId)
Record a task success and clear its failure count.