Heartbeat writing, world view building, and node lifecycle.
Each node writes a heartbeat file to object storage at a regular interval.
The WorldViewBuilder polls the heartbeat prefix to build a
WorldView — a snapshot of all known nodes and their status.
Structs
- Heartbeat
- A heartbeat written by a node to object storage.
- Heartbeat
Cache - Cache summary for a node.
- Heartbeat
Capacity - Capacity information for a node.
- Heartbeat
Load - Current load information for a node.
- Heartbeat
Writer - Writes the local node’s heartbeat to storage at a regular interval.
- Node
Status - Status of a single node in the world view.
- World
View - A snapshot of all known nodes in the swarm.
- World
View Builder - Periodically polls the heartbeat prefix and builds the world view.
Enums
- Node
State - The state of a node as observed via its heartbeat.