Module node

Module node 

The Apiary node โ€” a stateless compute instance in the swarm.

ApiaryNode is the main runtime entry point. It initialises the storage backend, detects system capacity, creates the bee pool, starts the heartbeat writer and world view builder, and manages the node lifecycle.

Structs

ApiaryNode
An Apiary compute node โ€” the runtime for one machine in the swarm.
ColonyStatus
Colony temperature and regulation status.
SwarmNodeInfo
Info about a single node in the swarm.
SwarmStatus
Summary of the swarm as seen by this node.